pub struct AppStartup<'raw> {
pub id: &'raw str,
pub app_type: u8,
}Fields
id: &'raw strapp_type: u8Trait Implementations
Sourceimpl<'raw> Clone for AppStartup<'raw>
impl<'raw> Clone for AppStartup<'raw>
Sourcefn clone(&self) -> AppStartup<'raw>
fn clone(&self) -> AppStartup<'raw>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'raw> Debug for AppStartup<'raw>
impl<'raw> Debug for AppStartup<'raw>
Sourceimpl<'raw> PartialEq for AppStartup<'raw>
impl<'raw> PartialEq for AppStartup<'raw>
Sourceimpl<'raw> Record<'raw> for AppStartup<'raw>
impl<'raw> Record<'raw> for AppStartup<'raw>
Sourceimpl<'raw> SubRecord<'raw> for AppStartup<'raw>
impl<'raw> SubRecord<'raw> for AppStartup<'raw>
const MIN_SERIALIZED_SIZE: usize
Sourcefn serialized_size(&self) -> usize
fn serialized_size(&self) -> usize
Exact size this will be once serialized in bytes. Read more
Sourcefn _serialize_chained<W: Write>(&self, dest: &mut W) -> SeResult<usize>
fn _serialize_chained<W: Write>(&self, dest: &mut W) -> SeResult<usize>
Should only be called from generated code!
Serialize this record. It is highly recommend to use a buffered writer.
Sourceunsafe fn _serialize_chained_unaligned<W: Write>(
zelf: *const Self,
dest: &mut W,
) -> SeResult<usize>
unsafe fn _serialize_chained_unaligned<W: Write>( zelf: *const Self, dest: &mut W, ) -> SeResult<usize>
Should only be called from generated code!
Serialize this record. It is highly recommend to use a buffered writer. Read more
Sourcefn _deserialize_chained(raw: &'raw [u8]) -> DeResult<(usize, Self)>
fn _deserialize_chained(raw: &'raw [u8]) -> DeResult<(usize, Self)>
Should only be called from generated code!
Deserialize this object as a sub component of a larger message. Returns a tuple of
(bytes_read, deserialized_value).
const EXACT_SERIALIZED_SIZE: Option<usize> = None
impl<'raw> StructuralPartialEq for AppStartup<'raw>