#[repr(packed(1))]pub struct AppStartupOutput {
pub success: bool,
}Fields
success: boolTrait Implementations
Sourceimpl Clone for AppStartupOutput
impl Clone for AppStartupOutput
Sourcefn clone(&self) -> AppStartupOutput
fn clone(&self) -> AppStartupOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AppStartupOutput
impl Debug for AppStartupOutput
Sourceimpl FixedSized for AppStartupOutput
impl FixedSized for AppStartupOutput
const SERIALIZED_SIZE: usize = _
Sourceimpl PartialEq for AppStartupOutput
impl PartialEq for AppStartupOutput
Sourceimpl<'raw> Record<'raw> for AppStartupOutput
impl<'raw> Record<'raw> for AppStartupOutput
Sourceimpl<'raw> SubRecord<'raw> for AppStartupOutput
impl<'raw> SubRecord<'raw> for AppStartupOutput
const MIN_SERIALIZED_SIZE: usize = Self::SERIALIZED_SIZE
const EXACT_SERIALIZED_SIZE: Option<usize>
Sourcefn serialized_size(&self) -> usize
fn serialized_size(&self) -> usize
Exact size this will be once serialized in bytes. Read more
Sourcefn _serialize_chained<W: Write>(&self, dest: &mut W) -> SeResult<usize>
fn _serialize_chained<W: Write>(&self, dest: &mut W) -> SeResult<usize>
Should only be called from generated code!
Serialize this record. It is highly recommend to use a buffered writer.
impl Copy for AppStartupOutput
impl StructuralPartialEq for AppStartupOutput