Struct atomic_websocket::schema::ValidClient
source · #[repr(packed(1))]pub struct ValidClient {
pub is_valid: bool,
}Fields
is_valid: boolTrait Implementations
sourceimpl Clone for ValidClient
impl Clone for ValidClient
sourcefn clone(&self) -> ValidClient
fn clone(&self) -> ValidClient
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ValidClient
impl Debug for ValidClient
sourceimpl FixedSized for ValidClient
impl FixedSized for ValidClient
const SERIALIZED_SIZE: usize = _
sourceimpl PartialEq for ValidClient
impl PartialEq for ValidClient
sourceimpl<'raw> Record<'raw> for ValidClient
impl<'raw> Record<'raw> for ValidClient
sourceimpl<'raw> SubRecord<'raw> for ValidClient
impl<'raw> SubRecord<'raw> for ValidClient
const MIN_SERIALIZED_SIZE: usize = 1usize
const EXACT_SERIALIZED_SIZE: Option<usize> = _
sourcefn serialized_size(&self) -> usize
fn serialized_size(&self) -> usize
Exact size this will be once serialized in bytes. Read more
sourcefn _serialize_chained<W: Write>(&self, dest: &mut W) -> SeResult<usize>
fn _serialize_chained<W: Write>(&self, dest: &mut W) -> SeResult<usize>
Should only be called from generated code!
Serialize this record. It is highly recommend to use a buffered writer.
impl Copy for ValidClient
impl StructuralPartialEq for ValidClient